SAREF v3.1.1 is a reference ontology for the IoT developed by ETSI SmartM2M in close interaction with the industry. SAREF contains core concepts that are common to several IoT domains and, to be able to handle specific data elements for a certain domain, dedicated extensions of SAREF have been created, for example SAREF4ENER [[i.4]](#[i.4]), SAREF4ENVI [[i.5]](#[i.5]), SAREF4BLDG [[i.6]](#[i.6]), and SAREF4CITY [[i.7]](#[i.7]), SAREF4INMA [[i.8]](#[i.8]), SAREF4AGRI [[i.9]](#[i.9]). Each domain can have one or more extensions, depending on the complexity of the domain. As a reference ontology, SAREF serves as the means to connect the extensions in different domains. The earlier document ETSI TR 103 411 [[i.10]](#[i.10]) specifies the rationale and methodology used to create, publish and maintain the SAREF extensions.

The present document is the technical specification of SAREF4SYST, a generic extension of ETSI TS 103 264 SAREF [[1]](#[1]) that defines an ontology pattern which can be instantiated for different domains. SAREF4SYST defines Systems, Connections between systems, and Connection Points at which systems may be connected. These core concepts can be used generically to define the topology of features of interest, and can be specialized for multiple domains. The topology of features of interest is highly important in many use cases. If a room holds a lighting device, and if it is adjacent with an open window to a room whose luminosity is low, then by turning on the lighting device in the former room one may expect that the luminosity in the latter room will rise.

The SAREF4SYST ontology pattern can be instantiated for different domains. For example to describe zones inside a building (systems), that share a frontier (connections). Properties of systems are typically state variables (e.g. agent population, temperature), whereas properties of connections are typically flows (e.g. heat flow).

SAREF4SYST has two main aims: on the one hand, to extend SAREF with the capability or representing general topology of systems and how they are connected or interact and, on the other hand, to exemplify how ontology patterns may help to ensure an homogeneous structure of the overall SAREF ontology and speed up the development of extensions.

SAREF4SYST consists both of a core ontology, and guidelines to create ontologies following the SAREF4SYST ontology pattern. The core ontology is a lightweight OWL-DL ontology that defines 3 classes and 9 object properties.

Use cases for ontology patterns are described extensively in ETSI TR 103 549 [[i.3]](#[i.3]). Clauses 4.2 and 4.3 extract use cases for the SAREF4SYST ontology pattern.

### Use case 1: Smart Energy

The present clause illustrates how SAREF4SYST can be used to homogeneously represent knowledge that is relevant for use cases in the Smart Energy domain:

- Electric power systems can exchange electricity with other electric power systems. The electric energy can flow both ways in some cases (from the Public Grid to a Prosumer), or in only one way (from the Public Grid to a Load). Electric power systems can be made up of different sub-systems. Generic sub-types of electric power systems include producers, consumers, storage systems, transmission systems. 
- Electric power systems may be connected one to another through electrical connection points. An Electric power system may have multiple connection points (Multiple Winding Transformer generally have one single primary winding with two or more secondary windings). Generic sub-types of electrical connection points include plugs, sockets, direct-current, single-phase, three-phase, connection points. 
- An Electrical connection may exist between two Electric power systems at two of their respective connection points. Generic sub-types of electrical connections include Single-phase Buses, Three-phase Buses. A single-phase electric power system can be connected using different configurations at a three-phase bus (RN, SN, TN types).

## Use case 2: Smart Building

The present clause illustrates how SAREF4SYST can be used to homogeneously represent knowledge that is relevant for use cases in the Smart Building domain:

- Buildings, Storeys, Spaces, are different sub-types of Zones. Zones can contain sub-zones. Zones can be adjacent or intersect with other zones. 
- Two zones may share one or more connections. For example some fresh air may be created inside a storey if it has two controllable openings to the exterior at different cardinal points. 

